@@ -761,6 +761,8 @@ class Function(Callable):
         self.shadows = None             # C symbol string
         self.moved_to = None            # namespaced function name string
         self.internal_skipped = False   # if True, this func will not be written to GIR
+        self.set_property = None        # Property name
+        self.get_property = None        # Property name
 
     def clone(self):
         clone = copy.copy(self)
@@ -981,12 +983,13 @@ class Bitfield(Node, Registered):
 
 class Member(Annotated):
 
-    def __init__(self, name, value, symbol, nick):
+    def __init__(self, name, value, symbol, nick=None, dump_name=None):
         Annotated.__init__(self)
         self.name = name
         self.value = value
         self.symbol = symbol
         self.nick = nick
+        self.dump_name = dump_name
         self.parent = None
 
     def _compare(self, other, op):
@@ -1196,7 +1199,8 @@ class Class(Node, Registered):
                  gtype_name=None,
                  get_type=None,
                  c_symbol_prefix=None,
-                 is_abstract=False):
+                 is_abstract=False,
+                 is_final=False):
         Node.__init__(self, name)
         Registered.__init__(self, gtype_name, get_type)
         self.ctype = ctype
@@ -1213,6 +1217,7 @@ class Class(Node, Registered):
         self.parent_chain = []
         self.glib_type_struct = None
         self.is_abstract = is_abstract
+        self.is_final = is_final
         self.methods = []
         self.virtual_methods = []
         self.static_methods = []
@@ -1302,6 +1307,8 @@ class Property(Node):
             self.transfer = PARAM_TRANSFER_NONE
         else:
             self.transfer = transfer
+        self.setter = None
+        self.getter = None
         self.parent = None  # A Class or Interface
 
 
