@@ -827,6 +827,12 @@ RegressTestObj*   regress_test_obj_new_from_file (const char *x, GError **error)
 _GI_TEST_EXTERN
 void       regress_test_obj_set_bare (RegressTestObj *obj, GObject *bare);
 
+_GI_TEST_EXTERN
+void       regress_test_obj_set_string (RegressTestObj *obj, const char *str);
+
+_GI_TEST_EXTERN
+const char *regress_test_obj_get_string (RegressTestObj *obj);
+
 _GI_TEST_EXTERN
 void       regress_test_obj_emit_sig_with_obj (RegressTestObj *obj);
 
